@@ -98,6 +98,7 @@ from _ped import DEVICE_DM
 from _ped import DEVICE_XVD
 from _ped import DEVICE_SDMMC
 from _ped import DEVICE_VIRTBLK
+from _ped import DEVICE_NVME
 
 from _ped import PARTITION_NORMAL
 from _ped import PARTITION_LOGICAL
@@ -133,6 +134,12 @@ if hasattr(_ped, 'PARTITION_ESP'):
 if hasattr(_ped, 'PARTITION_NONFS'):
     # pylint: disable=E0611
     from _ped import PARTITION_NONFS
+if hasattr(_ped, 'PARTITION_CHROMEOS_KERNEL'):
+    # pylint: disable=E0611
+    from _ped import PARTITION_CHROMEOS_KERNEL
+if hasattr(_ped, 'PARTITION_BLS_BOOT'):
+    # pylint: disable=E0611
+    from _ped import PARTITION_BLS_BOOT
 
 from _ped import DISK_CYLINDER_ALIGNMENT
 from _ped import DISK_GPT_PMBR_BOOT
@@ -325,7 +332,10 @@ archLabels = {'i386': ['msdos', 'gpt'],
               'ppc64le': ['msdos', 'gpt'],
               'x86_64': ['msdos', 'gpt'],
               'aarch64': ['msdos', 'gpt'],
-              'armv7l': ['msdos', 'gpt']}
+              'mips64': ['msdos','gpt'],
+              'armv7l': ['msdos', 'gpt'],
+              'riscv32': ['msdos', 'gpt'],
+              'riscv64': ['msdos', 'gpt']}
 
 # Adapted from:
 # http://stackoverflow.com/questions/922550/how-to-mark-a-global-as-deprecated-in-python
@@ -362,9 +372,9 @@ def Deprecated(mod, deprecated=None):
 __archLabels = (('amiga', 'ppc(64)?$'),
                 ('bsd', 'alpha$'),
                 ('dasd', 's390x?$'),
-                ('gpt', 'i[3-6]86$|x86_64$|ia64$|ppc(64|64le)?$|aarch64$|armv7l$'),
+                ('gpt', 'i[3-6]86$|x86_64$|ia64$|ppc(64|64le)?$|aarch64$|armv7l$|riscv(32|64)$'),
                 ('mac', 'ppc(64)?$'),
-                ('msdos', 'i[3-6]86$|x86_64$|s390x?$|alpha$|ia64$|ppc(64|64le)?$|aarch64$|armv7l$'),
+                ('msdos', 'i[3-6]86$|x86_64$|s390x?$|alpha$|ia64$|ppc(64|64le)?$|aarch64$|mips64$|armv7l$|riscv(32|64)$'),
                 ('sun', 'sparc(64)?$'))
 
 def getLabels(arch=None):
