@@ -1,7 +1,7 @@
 #
 # Python bindings for libparted (built on top of the _ped Python module).
 #
-# Copyright (C) 2009 Red Hat, Inc.
+# Copyright (C) 2009-2020 Red Hat, Inc.
 #
 # This copyrighted material is made available to anyone wishing to use,
 # modify, copy, or redistribute it subject to the terms and conditions of
@@ -18,9 +18,15 @@
 # Red Hat, Inc.
 #
 # Red Hat Author(s): Chris Lumens <clumens@redhat.com>
+#                    David Cantrell <dcantrell@redhat.com>
 #
 
-from collections import Sequence
+import sys
+
+if sys.version_info.major >= 3 and sys.version_info.minor >= 3:
+    from collections.abc import Sequence
+else:
+    from collections import Sequence
 
 class CachedList(Sequence):
     """CachedList()
