@@ -98,26 +98,22 @@ PyObject *_ped_Constraint_str(_ped_Constraint *self) {
     char *start_align = NULL, *end_align = NULL;
     char *start_range = NULL, *end_range = NULL;
 
-    start_align =
-PyUnicode_AsUTF8(_ped_Alignment_Type_obj.tp_repr(self->start_align));
+    start_align = (char *) PyUnicode_AsUTF8(_ped_Alignment_Type_obj.tp_repr(self->start_align));
     if (start_align == NULL) {
         return NULL;
     }
 
-    end_align =
-PyUnicode_AsUTF8(_ped_Alignment_Type_obj.tp_repr(self->end_align));
+    end_align = (char *) PyUnicode_AsUTF8(_ped_Alignment_Type_obj.tp_repr(self->end_align));
     if (end_align == NULL) {
         return NULL;
     }
 
-    start_range =
-PyUnicode_AsUTF8(_ped_Geometry_Type_obj.tp_repr(self->start_range));
+    start_range = (char *) PyUnicode_AsUTF8(_ped_Geometry_Type_obj.tp_repr(self->start_range));
     if (start_range == NULL) {
         return NULL;
     }
 
-    end_range =
-PyUnicode_AsUTF8(_ped_Geometry_Type_obj.tp_repr(self->end_range));
+    end_range = (char *) PyUnicode_AsUTF8(_ped_Geometry_Type_obj.tp_repr(self->end_range));
     if (end_range == NULL) {
         return NULL;
     }
