@@ -41,20 +41,21 @@ class PartitionFlagGetNameTestCase(unittest.TestCase):
                   'PARTITION_APPLE_TV_RECOVERY',
                   'PARTITION_BIOS_GRUB', 'PARTITION_DIAG',
                   'PARTITION_MSFT_DATA', 'PARTITION_IRST',
-                  'PARTITION_ESP']:
+                  'PARTITION_ESP', 'PARTITION_NONFS',
+                  'PARTITION_CHROMEOS_KERNEL', 'PARTITION_CHROMEOS_KERNEL']:
             if not hasattr(_ped, f):
                 continue
             attr = getattr(_ped, f)
             self.assertNotEqual(_ped.partition_flag_get_name(attr), "", "Could not get name for flag _ped.%s" % f)
 
         self.assertRaises(ValueError, _ped.partition_flag_get_name, -1)
-        self.assertRaises(ValueError, _ped.partition_flag_get_name, 1000)
+        self.assertRaises(_ped.PartedException, _ped.partition_flag_get_name, 1000)
 
 class PartitionFlagGetByNameTestCase(unittest.TestCase):
     def runTest(self):
         for f in ["boot", "root", "swap", "hidden", "raid", "lvm", "lba",
                   "hp-service", "palo", "prep", "msftres", "bios_grub",
-                  "msftdata", "irst", "esp"]:
+                  "msftdata", "irst", "esp", "nonfs"]:
             self.assertNotEqual(_ped.partition_flag_get_by_name(f), "", "Could not get flag %s" % f)
 
         self.assertEqual(_ped.partition_flag_get_by_name("nosuchflag"), 0)
@@ -82,7 +83,7 @@ class DiskFlagGetNameTestCase(unittest.TestCase):
             self.assertNotEqual(_ped.disk_flag_get_name(f), "", "Could not get name for flag %s" % f)
 
         self.assertRaises(ValueError, _ped.disk_flag_get_name, -1)
-        self.assertRaises(ValueError, _ped.disk_flag_get_name, 1000)
+        self.assertRaises(_ped.PartedException, _ped.disk_flag_get_name, 1000)
 
 class DiskFlagGetByNameTestCase(unittest.TestCase):
     def runTest(self):
@@ -224,10 +225,11 @@ class DeviceProbeAllTestCase(RequiresDevice, BuildList):
         # results.
         _ped.device_probe_all()
         lst = self.getDeviceList(_ped.device_get_next)
+        prefix = self.path[:self.path.index(self.temp_prefix) - 1] + "/" + self.temp_prefix
 
         self.assertGreater(len(lst), 0)
         self.assertGreater(
-            len([e for e in lst if e.path.startswith("/tmp/temp-device-")]), 0)
+            len([e for e in lst if e.path.startswith(prefix)]), 0)
 
 class DeviceFreeAllTestCase(RequiresDevice):
     def runTest(self):
